@@ -10,7 +10,7 @@ use Carp;
 
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(is_holiday holidays);
-our $VERSION   = '0.14';
+our $VERSION   = '0.15';
 
 our (%cached);
 
@@ -937,16 +937,20 @@ sub _compute_vic_labour_day {    # second monday in march
 sub _compute_vic_grand_final_eve_day {    # i have no words ...
     my ($year) = @_;
     my ( $day, $month );
-    if ( $year == 2016 ) {
-        $day   = 30;
-        $month = 8;
+    if ( $year < 2015 ) {
+        return ();
     }
     elsif ( $year == 2015 ) {
         $day   = 2;
         $month = 9;
     }
-    elsif ( $year < 2015 ) {
-        return ();
+    elsif ( $year == 2016 ) {
+        $day   = 30;
+        $month = 8;
+    }
+    elsif ( $year == 2017 ) {
+        $day   = 29;
+        $month = 8;
     }
     else {
         croak(
@@ -1231,6 +1235,10 @@ sub _compute_wa_queens_bday
         $day   = 25;
         $month = 8;
     }
+    elsif ( $year == 2018 ) {
+        $day   = 24;
+        $month = 8;
+    }
     else {
         croak(
             "Don't know how to calculate Queen's Birthday in WA for this year\n"
